DAT programName         byte "ParentObjectExample170114a", 0
CON '' Version Notes
{{
  170114a Program to demonstrate ways to pass data back and forth between parent and child
  objects.
  
}}
CON

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                    

  ' Below is a trick to define a second based on the clock settings.
  SECOND = ((_clkmode - xtal1) >> 6) * _xinfreq
  MILLISECOND = SECOND / 1000

  MAX_INTERVAL = 26000 ' in milliseconds
  
  BAUD = 115200
  QUOTE = 34
  
VAR

  long topObjectValueA
  long topObjectValueB
  long readFromChild
  long childCog
  
OBJ
    
    Child : "ChildExample170114a"
    Pst : "Parallax Serial Terminal"

PUB Start

  Pst.Start(BAUD)
   
  repeat
    result := Pst.RxCount
    Pst.Str(string(11, 13, "Press any key to begin."))
    waitcnt(clkfreq / 2 + cnt)
  until result
   
  Pst.RxFlush ' Clear out the character just entered.
   
  childCog := Child.Start(SECOND, @topObjectValueA)
   
  Pst.Clear
 
  MainLoop

PRI MainLoop

  repeat
    MainDisplay
    CheckForInput
    
PRI CheckForInput

  result := Pst.RxCount

  if result
    result := Pst.CharIn
    case result
      "a":
        Child.SetOneTimePointer(@topObjectValueA)
      "A":
        Child.ChangeParentPointer(@topObjectValueA)
      "b":
        Child.SetOneTimePointer(@topObjectValueB)
      "B":
        Child.ChangeParentPointer(@topObjectValueB)
      "c", "C":
        readFromChild := Child.GetValue
      "i", "I":
        ChangeCountInterval  
    
PRI MainDisplay

  Pst.ClearEnd
  Pst.NewLine
  Pst.ClearBelow
  Pst.Home
  Pst.Str(string(11, 13, "Parent and child object example program."))
  Pst.Str(string(11, 13, "Parent Object's Name = ", QUOTE))
  Pst.Str(@programName)
  Pst.Char(QUOTE)
  Pst.Str(string(11, 13, "Child Object's Name = ", QUOTE))
  Pst.Str(Child.GetObjectName)
  Pst.Char(QUOTE)
  Pst.Str(string(11, 13, "The child object is running in cog # "))
  Pst.Dec(childCog)
  Pst.Char(".")
  Pst.Str(string(11, 13, "This top object is running in cog # "))
  Pst.Dec(cogid)
  Pst.Char(".")
  Pst.ClearEnd
  Pst.NewLine
  Pst.Str(string(11, 13, "press ", QUOTE, "a", QUOTE, " to load count to "))
  Pst.Str(string(QUOTE, "topObjectValueA", QUOTE, " one time."))
  Pst.Str(string(11, 13, "press ", QUOTE, "A", QUOTE, " to send address of "))
  Pst.Str(string(QUOTE, "topObjectValueA", QUOTE, " to the child object."))
  Pst.Str(string(11, 13, "press ", QUOTE, "b", QUOTE, " to load count to "))
  Pst.Str(string(QUOTE, "topObjectValueB", QUOTE, " one time."))
  Pst.Str(string(11, 13, "press ", QUOTE, "B", QUOTE, " to send address of "))
  Pst.Str(string(QUOTE, "topObjectValueB", QUOTE, " to the child object."))
  Pst.Str(string(11, 13, "press ", QUOTE, "C", QUOTE, " to update value of "))
  Pst.Str(string(QUOTE, "readFromChild", QUOTE, " variable."))
  Pst.Str(string(11, 13, "press ", QUOTE, "I", QUOTE, " to change count interval"))
  Pst.Str(string(11, 13, 11, 13, "topObjectValueA = "))
  Pst.Dec(topObjectValueA)
  Pst.Str(string(11, 13, "topObjectValueB = "))
  Pst.Dec(topObjectValueB)
  Pst.Str(string(11, 13, "readFromChild = "))
  Pst.Dec(readFromChild)
  Pst.Str(string(11, 13, "Child.GetInterval (converted to milliseconds) = "))
  Pst.Dec(Child.GetInterval / MILLISECOND)
  Pst.Str(string(" ms"))
   
PRI ChangeCountInterval

  Pst.Str(string(11, 13, 11, 13, "Please enter new interval time in milliseconds:"))
  result := Pst.DecIn
  Pst.Str(string(11, 13, "You entered ", QUOTE))
  Pst.Dec(result)
  Pst.Str(string(QUOTE, " milliseconds."))
    
  if result > 0 and result < MAX_INTERVAL
    Child.SetInterval(result * MILLISECOND)
    Pst.Str(string(11, 13, 11, 13, "New interval has been set."))
  else
    Pst.Str(string(7, 11, 13, 11, 13, "Interval out of range. Try again.", 7))
    
  waitcnt(clkfreq * 2 + cnt)
